@@ -1,6 +1,6 @@
 package Pcore::API::Call::Action::Request;
 
-use Pcore qw[-class];
+use Pcore -class;
 use Pcore::API::Call::Action::Response;
 
 with qw[Pcore::API::Call::Action Pcore::Util::UA::Uploads];
@@ -11,8 +11,6 @@ has '+data' => ( isa => HashRef | ArrayRef );
 
 has is_response => ( is => 'lazy', isa => Bool, default => 0, init_arg => undef );
 
-no Pcore;
-
 sub BUILDARGS {
     my $self = shift;
     my $args = shift;
